==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/ToolActionLabelInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionInfoDescriptionMetadata } from "./ToolActionInfoDescriptionMetadata";
import { ToolActionLabelInfoDescription } from "./ToolActionLabelInfoDescription";
/**
 * @hidden
 */
export let ToolActionLabelInfoDescriptionMetadata = /*@__PURE__*/ (() => {
    class ToolActionLabelInfoDescriptionMetadata extends Base {
        static b(a) {
            if (ToolActionLabelInfoDescriptionMetadata.a == null) {
                ToolActionLabelInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ToolActionLabelInfoDescriptionMetadata.c(ToolActionLabelInfoDescriptionMetadata.a);
            }
            if (a.k(ToolActionLabelInfoDescriptionMetadata.a)) {
                return;
            }
            a.ab(ToolActionLabelInfoDescriptionMetadata.a);
        }
        static c(a) {
            ToolActionInfoDescriptionMetadata.c(a);
        }
        static d(a) {
            ToolActionLabelInfoDescriptionMetadata.b(a);
            a.ad("ToolActionLabelInfo", () => new ToolActionLabelInfoDescription());
            a.ac("ToolActionLabelInfo", ToolActionLabelInfoDescriptionMetadata.a);
        }
    }
    ToolActionLabelInfoDescriptionMetadata.$t = markType(ToolActionLabelInfoDescriptionMetadata, 'ToolActionLabelInfoDescriptionMetadata');
    ToolActionLabelInfoDescriptionMetadata.a = null;
    return ToolActionLabelInfoDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/ToolActionLabelInfoDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionInfoDescriptionMetadata } from "./ToolActionInfoDescriptionMetadata";
import { ToolActionLabelInfoDescription } from "./ToolActionLabelInfoDescription";
/**
 * @hidden
 */
export let ToolActionLabelInfoDescriptionMetadata = /*@__PURE__*/ (() => {
    class ToolActionLabelInfoDescriptionMetadata extends Base {
        static b(a) {
            if (ToolActionLabelInfoDescriptionMetadata.a == null) {
                ToolActionLabelInfoDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ToolActionLabelInfoDescriptionMetadata.c(ToolActionLabelInfoDescriptionMetadata.a);
            }
            if (a.k(ToolActionLabelInfoDescriptionMetadata.a)) {
                return;
            }
            a.ac(ToolActionLabelInfoDescriptionMetadata.a);
        }
        static c(a) {
            ToolActionInfoDescriptionMetadata.c(a);
        }
        static d(a) {
            ToolActionLabelInfoDescriptionMetadata.b(a);
            a.ae("ToolActionLabelInfo", () => new ToolActionLabelInfoDescription());
            a.ad("ToolActionLabelInfo", ToolActionLabelInfoDescriptionMetadata.a);
        }
    }
    ToolActionLabelInfoDescriptionMetadata.$t = markType(ToolActionLabelInfoDescriptionMetadata, 'ToolActionLabelInfoDescriptionMetadata');
    ToolActionLabelInfoDescriptionMetadata.a = null;
    return ToolActionLabelInfoDescriptionMetadata;
})();
